========================
Module - advanced_format
========================


This module provides for the following ansible plugin:

    * advanced_format


.. ansibleautoplugin::
   :module: validations_common/library/advanced_format.py
   :documentation: true
   :examples: true
